Structs
- Line
- Line
Column - The line and column of an offset in a source file.
- Line
Index - Index for fast byte offset to
LineColumnconversions. - Newline
With Trailing Newline - Like
UniversalNewlineIterator, but includes a trailing newline as an empty line. - OneIndexed
- Type-safe wrapper for a value whose logical range starts at
1, for instance the line or column numbers in a file - Source
Code - Gives access to the source code of a file and allows mapping between
TextSizeandLineColumn. - Source
File - A source file that is identified by its name. Optionally stores the source code and
LineIndex. - Source
File Builder - A Builder for constructing a
SourceFile - Source
Location - A position into a source file represented by the line number and the offset to that character relative to the start of that line.
- Universal
Newline Iterator - Like
str::lines, but accommodates LF, CRLF, and CR line endings, the latter of which are not supported bystr::lines.
Enums
- Line
Ending - The line ending style used in Python source code. See https://docs.python.org/3/reference/lexical_analysis.html#physical-lines
- Position
Encoding - Source
Row
Traits
- Line
Ranges - Extension trait for
strthat provides methods for working with ranges of lines. - Universal
Newlines - Extension trait for
strthat provides aUniversalNewlineIterator.
Functions
- find_
newline - Finds the next newline character. Returns its position and the
LineEnding.