pub struct LineColumn {
pub line: OneIndexed,
pub column: OneIndexed,
}Expand description
The line and column of an offset in a source file.
See LineIndex::line_column for more information.
Fields
line: OneIndexedThe line in the source text.
column: OneIndexedThe column (UTF scalar values) relative to the start of the line except any potential BOM on the first line.